@@ -1,6 +1,6 @@
 package Data::ModeMerge;
 
-use 5.010;
+use 5.010001;
 use Moo;
 
 use Data::Dumper;
@@ -10,7 +10,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(mode_merge);
 
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 sub mode_merge {
     my ($l, $r, $config_vars) = @_;
@@ -127,11 +127,11 @@ sub register_mode {
     if (ref($name0)) {
         my $obj = $name0;
     } elsif ($name0 =~ /^\w+(::\w+)+$/) {
-        eval "require $name0; \$obj = new $name0";
+        eval "require $name0; \$obj = $name0->new";
         die "Can't load module $name0: $@" if $@;
     } elsif ($name0 =~ /^\w+$/) {
         my $modname = "Data::ModeMerge::Mode::$name0";
-        eval "require $modname; \$obj = new $modname";
+        eval "require $modname; \$obj = $modname->new";
         die "Can't load module $modname: $@" if $@;
     } else {
         die "Invalid mode name $name0";
@@ -353,7 +353,7 @@ Data::ModeMerge - Merge two nested data structures, with merging modes and optio
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -367,7 +367,7 @@ version 0.29
     # modules (e.g. Hash::Merge or Data::Merger), turn off modes
     # (prefix) parsing and options key parsing.
 
-    my $mm = new Data::ModeMerge(config => {parse_prefix=>0, options_key=>undef});
+    my $mm = Data::ModeMerge->new(config => {parse_prefix=>0, options_key=>undef});
     my $res = $mm->merge($hash1, $hash2);
     die $res->{error} if $res->{error};
     # $res->{result} -> { a=>2, c=>1, "-c"=>2, d=>{da=>[1], "+da"=>[2]} }
@@ -760,7 +760,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
